@@ -16,6 +16,8 @@ class Clock(IntervalModule):
     format = None
     interval = 1
 
+    c = ["#ffffff", "#cccccc"]
+
     def init(self):
         if self.format is None:
             #
@@ -41,8 +43,9 @@ class Clock(IntervalModule):
                 self.format = "%a %-d %b %X"
 
     def run(self):
+        self.c.reverse()
         self.output = {
             "full_text": datetime.datetime.now().strftime(self.format),
             "urgent": False,
-            "color": "#ffffff"
+            "color": self.c[0],
         }
