@@ -20,3 +20,21 @@ def display_notification(title, body, icon="dialog-information", urgency=1, time
         notification.set_timeout(timeout)
     notification.set_urgency(URGENCY_LUT[urgency])
     return notification.show()
+
+try:
+    from PyQt4 import Qt
+
+    app = Qt.QApplication([])
+
+    def display_menu(menu_items, x, y):
+        menu = Qt.QMenu()
+
+        for label, callable in menu_items:
+            action = menu.addAction(label)
+            action.triggered.connect(callable)
+
+        menu.popup(Qt.QPoint(x, y))
+        menu.exec_()
+except ImportError:
+    def display_menu(menu_items, x, y):
+        pass
