@@ -11,12 +11,14 @@ import i3pystatus.mail
 
 from .core.imputil import ClassFinder
 
-IGNORE = ("__main__", "mkdocs")
+IGNORE = ("__main__", "mkdocs", "core")
 MODULE_FORMAT = """
 {heading} {name}
 
 {doc}
 
+__Settings:__
+
 {settings}
 
 {endstring}\n"""
